<?php
namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ova_artist extends Widget_Base {

	public function get_name() {
		return 'ova_artist';
	}

	public function get_title() {
		return __( 'Ova Speakers', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-person';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Speakers', 'ova-framework' ),
			]
		);

		$this->add_control(
			'sk_version',
			[
				'label'   => __('Version','ova-framework'),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'version_1',
				'options' => [
					'version_1' => __('Version 1','ova-framework'),
					'version_2' => __('Version 2','ova-framework'),
				]	
			]
		);

		$this->add_control(
			'show_popup',
			[
				'label'        => __( 'Using Popup', 'ova-framework' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'ova-framework' ),
				'label_off'    => __( 'Hide', 'ova-framework' ),
				'return_value' => 'yes',
				'default'      => 'no',
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => __( 'Image', 'ova-framework' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'name',
			[
				'label'   => __( 'Name', 'ova-framework' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __('Nimrod Barshad', 'ova-framework'),
			]
		);

		$this->add_control(
			'skill',
			[
				'label'   => __( 'Skill', 'ova-framework' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __('Painter, Sculptor, Conceptual Artist', 'ova-framework'),
			]
		);

		$this->add_control(
			'phone',
			[
				'label'   => __( 'Phone', 'ova-framework' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __('+61 98654 3210', 'ova-framework'),
				'conditions' => [
					'terms'    => [
						[
							'name'  => 'sk_version',
							'value' => 'version_1',
						],
					],
				]
			]
		);

		$this->add_control(
			'email',
			[
				'label'   => __( 'Email', 'ova-framework' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __('E-mail', 'ova-framework'),
				'conditions' => [
					'terms'    => [
						[
							'name'  => 'sk_version',
							'value' => 'version_1',
						],
					],
				]
			]
		);

		$this->add_control(
			'link_email',
			[
				'label'   => __( 'Link Email', 'ova-framework' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => __('someone@example.com', 'ova-framework'),
				'conditions' => [
					'terms'    => [
						[
							'name'  => 'sk_version',
							'value' => 'version_1',
						],
					],
				]
			]
		);

		$this->add_control(
			'link',
			[
				'label'         => __( 'Link', 'ova-framework' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'show_external' => false,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'icon',
			[
				'label' => __( 'Description Strong', 'ova-framework' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
				'rows'  => 2,
			]
		);

		$repeater->add_control(
			'link_icon',
			[
				'label'       => __( 'Link', 'ova-framework' ),
				'type'        => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
				'default'     => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'tabs',
			[
				'label'   => __( 'Tabs', 'ova-framework' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => [
					[
						'icon' => __('fa fa-facebook', 'ova-framework'),
					],
					[
						'icon' => __('fa fa-twitter', 'ova-framework'),
					],
					[
						'icon' => __('fa fa-tumblr', 'ova-framework'),
					],
					[
						'icon' => __('fa fa-pinterest-p', 'ova-framework'),
					],
					
				],
				'title_field' => '{{{ icon }}}',
			]
		);

		// $this->add_responsive_control(
		// 	'align',
		// 	[
		// 		'label' => __( 'Alignment', 'elementor' ),
		// 		'type' => Controls_Manager::CHOOSE,
		// 		'options' => [
		// 			'left'    => [
		// 				'title' => __( 'Left', 'elementor' ),
		// 				'icon' => 'fa fa-align-left',
		// 			],
		// 			'center' => [
		// 				'title' => __( 'Center', 'elementor' ),
		// 				'icon' => 'fa fa-align-center',
		// 			],
		// 			'right' => [
		// 				'title' => __( 'Right', 'elementor' ),
		// 				'icon' => 'fa fa-align-right',
		// 			],
		// 		],
		// 		'default' => 'center',
		// 		'selectors' => [
		// 			'{{WRAPPER}} .ova-artist .items-artist' => 'text-align: {{VALUE}};',
		// 		],
		// 	]
		// );

		$this->add_control(
			'image_popup',
			[
				'label'   => __( 'Image Popup', 'ova-framework' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'conditions'   => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'name_popup',
			[
				'label'      => __( 'Name Popup', 'ova-framework' ),
				'type'       => Controls_Manager::TEXT,
				'default'    => __('Nimrod Barshad', 'ova-framework'),
				'conditions' => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'skill_popup',
			[
				'label'      => __( 'Job Popup', 'ova-framework' ),
				'type'       => Controls_Manager::TEXTAREA,
				'row'        => 2,
				'default'    => __("Painter, Sculptor, Conceptual Artist", "ova-framework"),
				'conditions' => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->add_control(
			'content_popup',
			[
				'label'      => __( 'Content Popup', 'ova-framework' ),
				'type'       => Controls_Manager::TEXTAREA,
				'row'        => 2,
				'default'    => __("Augue ut lectus arcu bibendum at varius vel pharetra vel. Vestibulum lorem sed risus ultricies. In curs turpis massa tincidunt dui ut ornare.", "ova-framework"),
				'conditions' => [
					'terms'    => [
						[
							'name'  => 'show_popup',
							'value' => 'yes',
						],
					],
				]
			]
		);

		$this->end_controls_section();
		// end tab section_content

		//section style Box
		$this->start_controls_section(
			'section_box',
			[
				'label' => __( 'Background Overlay', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background_overlay_hover',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .ova-media.pop-media:after',
			]
		);

		$this->end_controls_section();

		//section style Box
		$this->start_controls_section(
			'section_box_icon',
			[
				'label' => __( 'Background Icon', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'conditions' => [
					'terms'    => [
						[
							'name'  => 'sk_version',
							'value' => 'version_2',
						],
					],
				]
			]
		);

		$this->start_controls_tabs('icon_style');
		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'ova-framework' ),
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background_icon',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .ova-media.pop-media:after',
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'ova-framework' ),
			]
		);

		$this->add_control(
			'icon_background_color_hover',
			[
				'label' => __('Background','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{ WRAPPER }} .ova-speakers .items-speakers.version_2 .ova-content .list-con ul li a:hover' => 'background-color: {{VALUE}} !important;'
				]
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'section_box_name',
			[
				'label' => __( 'Name', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'name_typography',
				'label'    => __( 'Typography', 'ova-framework' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .ova-content .name',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label' => __('Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .name' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_control(
			'name_color_hover',
			[
				'label' => __('Color Hover','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .name:hover' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control(
			'name_margin',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_box_skill',
			[
				'label' => __( 'Skill', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'skill_typography',
				'label'    => __( 'Typography', 'ova-framework' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .ova-content .skill',
			]
		);

		$this->add_control(
			'skill_color',
			[
				'label' => __('Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .skill' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control(
			'skill_margin',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .skill' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_box_phone',
			[
				'label' => __( 'Phone/Mail', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'phone_typography',
				'label'    => __( 'Typography', 'ova-framework' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .ova-content .contact a',
			]
		);

		$this->add_control(
			'phone_color',
			[
				'label' => __('Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .contact a' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_control(
			'phone_color_hover',
			[
				'label' => __('Hover','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .contact a:hover' => 'color: {{VALUE}}; border-color: {{VALUE}};',
				]
			]
		);

		$this->add_control(
			'phone_color_boder',
			[
				'label' => __('Mail Border Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .contact a.email' => 'border-color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control(
			'phone_margin',
			[
				'label' => __( 'Margin', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .ova-content .contact' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_popup_content',
			[
				'label' => __( 'Popup Content', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'name_options',
			[
				'label' => __( 'Name Popup', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'name_popup_typography',
				'label'    => __( 'Typography', 'ova-framework' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content h3',
			]
		);

		$this->add_control(
			'name_popup_color',
			[
				'label' => __('Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content h3' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control(
			'name_popup_padding',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'skill_options',
			[
				'label' => __( 'Skill Popup', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'skill_popup_typography',
				'label'    => __( 'Typography', 'ova-framework' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content span.job',
			]
		);

		$this->add_control(
			'skill_popup_color',
			[
				'label' => __('Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content span.job' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control(
			'skill_popup_padding',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content span.job' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'content_options',
			[
				'label' => __( 'Content Popup', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'content_popup_typography',
				'label'    => __( 'Typography', 'ova-framework' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content p',
			]
		);

		$this->add_control(
			'content_popup_color',
			[
				'label' => __('Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content p' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control(
			'content_popup_padding',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'social_options',
			[
				'label' => __( 'Social Popup', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_size',
			[
				'label' => __( 'Icon Size', 'ova-framework' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content .list-con ul li a i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_popup_color',
			[
				'label' => __('Color','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content .list-con ul li a i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content .list-con ul li a' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content .list-con ul li a:hover' => 'background-color: {{VALUE}};'
				]
			]
		);

		$this->add_control(
			'icon_popup_color_hover',
			[
				'label' => __('Hover','ova-framework'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-speakers .items-speakers .popup_volunteer .content_popup .volunteer-popup-content .list-con ul li a:hover i' => 'color: {{VALUE}};'
				]
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$tabs = $settings['tabs'];

		$pop_class = '';

		if( $settings['show_popup'] === 'yes' ){
			$pop_class = 'pop-media';
		}
		?>
		<div class="ova-speakers">
			<div class="items-speakers <?php echo esc_attr($settings['sk_version']);?>">
				<div class="ova-media <?php echo esc_attr($pop_class);?>">
					<a class="img" href="<?php echo esc_attr($settings['link']['url']); ?>">
						<img src="<?php echo esc_attr($settings['image']['url']); ?>" alt="">
					</a>
				</div>

				<?php if( $settings['show_popup'] === 'yes' ) : ?>
					<div class="popup_volunteer">					
						<a class="view_volunteer"><i class="icon_plus"></i></a>
						<div class="content_popup">
							<div class="container bgr-popup">
								<span class="btn_close icon_close"></span>
								<div class="row">
									<div class="col-lg-6 col-md-4">
										<div class="volunteer-popup-img">
											<img src="<?php echo esc_attr($settings['image_popup']['url']) ?>" alt="<?php echo esc_attr($settings['name_popup']); ?>">
										</div>
									</div>
									<div class="col-lg-6 col-md-8">
										<div class="volunteer-popup-content">
											<h3 class="second_font"><?php echo esc_html($settings['name_popup']); ?></h3>
											<span class="job"><?php echo esc_html($settings['skill_popup']);?></span>
											<p><?php echo esc_html( $settings['content_popup'] );?></p>
											<div class="list-con">
												<ul>
													<?php if (!empty($tabs)) : foreach($tabs as $item) : ?>

														<?php 
														$target =  ( $item['link_icon']['is_external'] ? ' target="_blank" ' : '' );
														$rel =  ( $item['link_icon']['nofollow'] ? ' rel="nofollow" ' : '' );
														?>
														<li><a <?php echo $target . '' . $rel; ?> href="<?php echo esc_attr($item['link_icon']['url']) ?>"><i class="<?php echo esc_attr($item['icon']) ?>"></i></a></li>
													<?php endforeach; endif; ?>
												</ul>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				<?php endif; ?>
				
				<div class="ova-content">
					<a class="name second_font" href="<?php echo esc_attr($settings['link']['url']); ?>">
						<?php echo esc_html($settings['name']) ?>
					</a>
					<?php if ($settings['skill'] != '') { ?>
						<div class="skill"> 
							<?php echo esc_html($settings['skill']);  ?>
						</div>
					<?php } ?>
					<?php if( $settings['phone'] != '' ||  $settings['email'] != '' ) : ?>
						<div class="contact">
							<?php 
							if ($settings['phone'] != '') { 
								$phone = preg_replace('/[^0-9+]/', '', $settings['phone'] );
								?>
								<a class="phone" href="tel:<?php echo esc_attr($phone) ?>" > 
									<i class="ti-mobile"></i><?php echo esc_html($settings['phone'] );  ?>
								</a>
							<?php } ?>
							<?php if ($settings['phone'] != '' && $settings['email'] != '') {    ?>
								<span class="slack">/</span>
							<?php } ?>
							<?php if ($settings['email'] != '') { ?>
								<a class="email" href="mailto:<?php echo sanitize_email($settings['link_email']); ?>"> 
									<i class="ti-email"></i><?php echo esc_html($settings['email']);  ?>
								</a>
							<?php } ?>
						</div>
					<?php endif;?>
					<?php if($settings['sk_version'] == 'version_2') : ?>
						<div class="list-con">
							<ul>
								<?php if (!empty($tabs)) : foreach($tabs as $item) : ?>
									<?php 
									$target =  ( $item['link_icon']['is_external'] ? ' target="_blank" ' : '' );
									$rel =  ( $item['link_icon']['nofollow'] ? ' rel="nofollow" ' : '' );
									?>
									<li><a <?php echo $target . '' . $rel; ?> href="<?php echo esc_attr($item['link_icon']['url']) ?>"><i class="<?php echo esc_attr($item['icon']) ?>"></i></a></li>
								<?php endforeach; endif; ?>
							</ul>
						</div>
					<?php endif;?>
				</div>
				
			</div>
		</div>
		<?php
	}
}
