<?php
namespace ova_framework\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_banner_time_countdown extends Widget_Base {

	public function get_name() {
		return 'ova_banner_time_countdown';
	}

	public function get_title() {
		return __( 'Baner Time Countdown', 'ova-framework' );
	}

	public function get_icon() {
		return 'fa fa-clock-o';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		wp_enqueue_script( 'jquery-countdown-plugin', OVA_PLUGIN_URI.'/assets/libs/jquery-countdown/jquery.plugin.min.js', array(), null );
		wp_enqueue_script( 'jquery-countdown', OVA_PLUGIN_URI.'/assets/libs/jquery-countdown/jquery.countdown.min.js', array(), null );

		$language =  get_theme_mod( 'choice_language' );
		if ($language != '') {
			wp_enqueue_script( 'jquery-countdown-', OVA_PLUGIN_URI.'/assets/libs/jquery-countdown/jquery.countdown-'.$language.'.js', array(), null );
		}
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		


		/*************** Section Countdouwn Offers ***************/
		$this->start_controls_section(
			'section_countdown',
			[
				'label' => __( 'Countdown', 'ova-framework' ),
			]
		);
		$this->add_control(
			'due_date',
			[
				'label' => __( 'Due Date', 'ova-framework' ),
				'type' => Controls_Manager::DATE_TIME,
				'default' => date( 'Y-m-d H:i', strtotime( '+1 day' ) + ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS ) ),
				'description' => sprintf( __( 'Date set according to your timezone: %s.', 'ova-framework' ), Utils::get_timezone_string() ),
				'separator' => 'after',
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'row' => 2,
				'default' => __('THE LEADING STARTUP EVENT', 'ova-framework'),
			]
		);

		$this->add_control(
			'desc',
			[
				'label' => __( 'Description', 'ova-framework' ),
				'type' => Controls_Manager::TEXTAREA,
				'row' => 2,
				'default' => __('BRIGHTON, MARCH 21-23, 2019', 'ova-framework'),
			]
		);

		$this->add_control(
			'text_button',
			[
				'label' => __( 'Text Button', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Buy Ticket', 'ova-framework'),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Link', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
				'show_external' => false,
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'number_countdown',
			[
				'label' => __( 'Number', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number_countdown_typo',
				'selector' => '{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section .countdown-amount',
			]
		);

		$this->add_control(
			'number_countdown_color',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section .countdown-amount' => 'color: {{VALUE}}',
				],
			]
		);


		$this->add_control(
			'label_countdown',
			[
				'label' => __( 'Label', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'label_typo',
				'selector' => '{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section .countdown-period',
			]
		);

		$this->add_control(
			'period_color',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section .countdown-period' => 'color: {{VALUE}}',
				],
			]
		);


		$this->add_control(
			'show_days',
			[
				'label' => __( 'Days', 'ova-framework' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'ova-framework' ),
				'label_off' => __( 'Hide', 'ova-framework' ),
				'default' => 'yes',
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section:nth-child(1)' => 'display: inline-block;',
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'show_hours',
			[
				'label' => __( 'Hours', 'ova-framework' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'ova-framework' ),
				'label_off' => __( 'Hide', 'ova-framework' ),
				'default' => 'yes',
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section:nth-child(2)' => 'display: inline-block;',
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section:nth-child(1) .countdown-amount:after' => 'content: ":";'
				],
			]
		);

		$this->add_control(
			'show_minutes',
			[
				'label' => __( 'Minutes', 'ova-framework' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'ova-framework' ),
				'label_off' => __( 'Hide', 'ova-framework' ),
				'default' => 'yes',
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section:nth-child(3)' => 'display: inline-block;',
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section:nth-child(2) .countdown-amount:after' => 'content: ":";'
				],
			]
		);

		$this->add_control(
			'show_seconds',
			[
				'label' => __( 'Seconds', 'ova-framework' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'ova-framework' ),
				'label_off' => __( 'Hide', 'ova-framework' ),
				'default' => 'yes',
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section:nth-child(4)' => 'display: inline-block;',
					'{{WRAPPER}} .ova_baner_time_countdown .due_date .countdown-row .countdown-section:nth-child(3) .countdown-amount:after' => 'content: ":";'
				],
			]
		);


		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left'    => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				],
			]
		);


		$this->add_control(
			'margin_box',
			[
				'label' => __( 'Space Countdown', 'ova-framework' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => -200,
						'max' => 200,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .due_date' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Title', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .ova_baner_time_countdown .title h3',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_title',
			[
				'label' => __( 'Color Title', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .title h3' => 'color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		//END SECTION TAB STYLE TITLE

		//SECTION TAB STYLE DESCRIPTION
		$this->start_controls_section(
			'section_desc',
			[
				'label' => __( 'Description', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'desc_typography',
				'selector' => '{{WRAPPER}} .ova_baner_time_countdown .desc p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_desc',
			[
				'label' => __( 'Color Description', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .desc p' => 'color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		//END SECTION TAB STYLE DESCRIPTION


		//SECTION TAB STYLE BUTTON
		$this->start_controls_section(
			'section_button',
			[
				'label' => __( 'Button', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .ova_baner_time_countdown .button .text-button',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'color_button',
			[
				'label' => __( 'Color Button', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .button .text-button' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_button_hover',
			[
				'label' => __( 'Color Button Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .button .text-button:hover' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bg_color_button',
			[
				'label' => __( 'Background Color Button', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .button .text-button' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'bg_color_button_hover',
			[
				'label' => __( 'Background Color Button Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova_baner_time_countdown .button .text-button:hover' => 'background-color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		//END SECTION TAB STYLE BUTTON



		
	}
	protected function render() {
		$settings = $this->get_settings();
		$due_date = $settings['due_date'];
		?>
		<div class="ova_baner_time_countdown">
			<div class="due_date" data-day="<?php echo $due_date; ?>"></div>
			<div class="title">
				<h3 class="title"><?php echo esc_html($settings['title']) ?></h3>
			</div>
			<div class="desc">
				<p class="desc"><?php echo esc_html($settings['desc']) ?></p>
			</div>
			<div class="button">
				<a href="<?php echo esc_attr($settings['link']['url']) ?>" class="text-button"><?php echo esc_html($settings['text_button']) ?></a>
			</div>
		</div>
		<?php
	}
}