<?php
namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ova_lifevent_according_image extends Widget_Base {

	public function get_name() {
		return 'ova_lifevent_according_image';
	}

	public function get_title() {
		return __( 'Schedule According Image', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-accordion';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'owl-carousel', OVA_PLUGIN_URI.'assets/libs/owl-carousel/assets/owl.carousel.min.css' );
		wp_enqueue_script( 'owl-carousel', OVA_PLUGIN_URI.'assets/libs/owl-carousel/owl.carousel.min.js', array('jquery'), false, true );
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_version',
			[
				'label' => __( 'Version', 'ova-framework' ),
			]
		);

		$this->add_control(
			'version',
			[
				'label' => __( 'Version', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'version_1',
				'options' => [
					'version_1'  => __( 'Version 1', 'ova-framework' ),
					'version_2' => __( 'Version 2', 'ova-framework' ),
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Schedule According', 'ova-framework' ),
			]
		);


		$this->add_control(
			'wp_title',
			[
				'label' => __( 'Title', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Lunch break', 'ova-framework'),
				'condition' => [
					'version' => 'version_1'
				],
			]
		);

		$this->add_control(
			'wp_time',
			[
				'label' => __( 'Time', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('2:00pm', 'ova-framework'),
				'condition' => [
					'version' => 'version_1'
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'open',
			[
				'label' => __( 'Open', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'ova-framework' ),
				'label_off' => __( 'Hide', 'ova-framework' ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$repeater->add_control(
			'class_day_filter',
			[
				'label' => __( 'Class Day Filter', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'day_filter_1',
			]
		);

		$repeater->add_control(
			'class_room_filter',
			[
				'label' => __( 'Class Room Filter', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'room_filter_1',
			]
		);

		$repeater->add_control(
			'time',
			[
				'label' => __( 'Time', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('12:30pm', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'title',
			[
				'label' => __( 'Title', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Innovation & Technology', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'location',
			[
				'label' => __( 'Location', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Hall A', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'location_icon',
			[
				'label' => __( 'Location Icon Class', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-location-pin',
			]
		);

		$repeater->add_control(
			'level',
			[
				'label' => __( 'Level', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Beginner', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'level_icon',
			[
				'label' => __( 'User Icon', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-user',
			]
		);

		

		$repeater->add_control(
			'content',
			[
				'label' => __( 'Content', 'ova-framework' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __('We care for more than 200 thousand exhibits spanning billions of years and welcome more than five million way
					visitors annually.', 'ova-framework'),
				'placeholder' => __( 'Type your content here', 'ova-framework' ),
			]
		);

		$repeater->add_control(
			'speaker1_img',
			[
				'label' => __( 'Image Speaker 1', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$repeater->add_control(
			'speaker1_name',
			[
				'label' => __( 'Speaker 1 Name', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker1_job',
			[
				'label' => __( 'Speaker Job 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker1_link',
			[
				'label' => __( 'Link Speaker 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker1_icon1',
			[
				'label' => __( 'Speaker Icon 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-facebook',
			]
		);

		$repeater->add_control(
			'speaker1_icon1_link',
			[
				'label' => __( 'Speaker Icon Link 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'https://facebook.com',
			]
		);

		$repeater->add_control(
			'speaker1_icon2',
			[
				'label' => __( 'Speaker Icon 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-twitter-alt',
			]
		);

		$repeater->add_control(
			'speaker1_icon2_link',
			[
				'label' => __( 'Speaker Icon Link 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'https://twitter.com',
			]
		);

		$repeater->add_control(
			'speaker1_icon3',
			[
				'label' => __( 'Speaker Icon 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-youtube',
			]
		);

		$repeater->add_control(
			'speaker1_icon3_link',
			[
				'label' => __( 'Speaker Icon Link 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'https://youtube.com',
			]
		);

		/* Repeater Speaker 2 */
		$repeater->add_control(
			'speaker2_img',
			[
				'label' => __( 'Image Speaker 2', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$repeater->add_control(
			'speaker2_name',
			[
				'label' => __( 'Speaker 2 Name', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker2_job',
			[
				'label' => __( 'Speaker Job 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker2_link',
			[
				'label' => __( 'Link Speaker 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker2_icon1',
			[
				'label' => __( 'Speaker Icon 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-facebook',
			]
		);

		$repeater->add_control(
			'speaker2_icon1_link',
			[
				'label' => __( 'Speaker Icon Link 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'https://facebook.com',
			]
		);

		$repeater->add_control(
			'speaker2_icon2',
			[
				'label' => __( 'Speaker Icon 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-twitter-alt',
			]
		);

		$repeater->add_control(
			'speaker2_icon2_link',
			[
				'label' => __( 'Speaker Icon Link 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'https://twitter.com',
			]
		);

		$repeater->add_control(
			'speaker2_icon3',
			[
				'label' => __( 'Speaker Icon 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-youtube',
			]
		);

		$repeater->add_control(
			'speaker2_icon3_link',
			[
				'label' => __( 'Speaker Icon Link 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'https://youtube.com',
			]
		);

		/* Repeater Speaker 3 */
		$repeater->add_control(
			'speaker3_img',
			[
				'label' => __( 'Image Speaker 3', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$repeater->add_control(
			'speaker3_name',
			[
				'label' => __( 'Speaker 3 Name', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker3_job',
			[
				'label' => __( 'Speaker Job 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker3_link',
			[
				'label' => __( 'Link Speaker 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker3_icon1',
			[
				'label' => __( 'Speaker Icon 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker3_icon1_link',
			[
				'label' => __( 'Speaker Icon Link 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker3_icon2',
			[
				'label' => __( 'Speaker Icon 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker3_icon2_link',
			[
				'label' => __( 'Speaker Icon Link 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker3_icon3',
			[
				'label' => __( 'Speaker Icon 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		
		$repeater->add_control(
			'speaker3_icon3_link',
			[
				'label' => __( 'Speaker Icon Link 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		/* Repeater Speaker 4 */
		$repeater->add_control(
			'speaker4_img',
			[
				'label' => __( 'Image Speaker 4', 'ova-framework' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$repeater->add_control(
			'speaker4_name',
			[
				'label' => __( 'Speaker 4 Name', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker4_job',
			[
				'label' => __( 'Speaker Job 4', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker4_link',
			[
				'label' => __( 'Link Speaker 4', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'speaker4_icon1',
			[
				'label' => __( 'Speaker Icon 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker4_icon1_link',
			[
				'label' => __( 'Speaker Icon Link 1', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker4_icon2',
			[
				'label' => __( 'Speaker Icon 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker4_icon2_link',
			[
				'label' => __( 'Speaker Icon Link 2', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'speaker4_icon3',
			[
				'label' => __( 'Speaker Icon 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		
		$repeater->add_control(
			'speaker4_icon3_link',
			[
				'label' => __( 'Speaker Icon Link 3', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Link', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( '#', 'ova-framework' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$repeater->add_control(
			'text_button',
			[
				'label' => __( 'Text Button', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Read More', 'ova-framework'),
			]
		);


		$this->add_control(
			'tabs_lifevent_according_image',
			[
				'label' => __( 'Items', 'elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'open' => '',
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->end_controls_section();
		// end tab section_content

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$tabs_content = $settings['tabs_lifevent_according_image'];
		$id_int = substr( $this->get_id_int(), 0, 3 );
		$version = $settings['version'];
		?>

		<div class="ova_lifevent_according_image wp-ova-according-<?php echo esc_attr($id_int) ?> <?php echo esc_attr($version) ?>">
			


			<?php
			if (!empty($tabs_content)) :
				$i=$id_int;
				foreach ($tabs_content as $item) :
					$i++;

					if ($item['open'] == 'yes' || $version === 'version_2') {
						$class_active = " show ";
						$icon_active = " fa fa-angle-up ";
					} else {
						$class_active = " hide ";
						$icon_active = " fa fa-angle-down ";
					}
					
					$speaker1_img = wp_get_attachment_image_src( $item['speaker1_img']['id'], 'lifevent_thumbnail_schedule' );
					$speaker2_img = wp_get_attachment_image_src( $item['speaker2_img']['id'], 'lifevent_thumbnail_schedule' );
					$speaker3_img = wp_get_attachment_image_src( $item['speaker3_img']['id'], 'lifevent_thumbnail_schedule' );
					$speaker4_img = wp_get_attachment_image_src( $item['speaker4_img']['id'], 'lifevent_thumbnail_schedule' );

					$speaker1_img_200 = wp_get_attachment_image_src( $item['speaker1_img']['id'], 'lifevent_thumbnail_schedule_200' );
					$speaker2_img_200 = wp_get_attachment_image_src( $item['speaker2_img']['id'], 'lifevent_thumbnail_schedule_200' );
					$speaker3_img_200 = wp_get_attachment_image_src( $item['speaker3_img']['id'], 'lifevent_thumbnail_schedule_200' );
					$speaker4_img_200 = wp_get_attachment_image_src( $item['speaker4_img']['id'], 'lifevent_thumbnail_schedule_200' );


					$class_room_filter = $item['class_room_filter'];
					$class_day_filter = $item['class_day_filter'];
					?>
					<div class="item-room <?php echo esc_attr($class_room_filter) ?> <?php echo esc_attr($class_day_filter) ?>">
						<div class="accor-lifevent-content-image <?php echo esc_attr($class_active) ?> ">
							<div class="wp-time">
								<span><?php echo esc_html($item['time']) ?></span>
							</div>
							<div class="wp-content">

								<?php if(  $speaker1_img[0] || $speaker2_img[0]  ){ ?>
									<div class="speaker_imgs owl-carousel">

										<?php if(  $speaker1_img[0]  ){ ?>
											<img src="<?php echo esc_url( $speaker1_img[0] ); ?>" alt="<?php echo esc_attr($item['speaker1_name']) ?>">
										<?php } ?>

										<?php if(  $speaker2_img[0]  ){ ?>
											<img src="<?php echo esc_url( $speaker2_img[0] ); ?>" alt="<?php echo esc_attr($item['speaker2_name']) ?>">	
										<?php } ?>

										<?php if(  $speaker3_img[0]  ){ ?>
											<img src="<?php echo esc_url( $speaker3_img[0] ); ?>" alt="<?php echo esc_attr($item['speaker3_name']) ?>">	
										<?php } ?>

										<?php if(  $speaker4_img[0]  ){ ?>
											<img src="<?php echo esc_url( $speaker4_img[0] ); ?>" alt="<?php echo esc_attr($item['speaker4_name']) ?>">	
										<?php } ?>


									</div>
								<?php } ?>

								<div class="sub-content">
									<div class="wp-title" data-option="<?php echo esc_attr($id_int) ?>">
										
										

										<span class="title" ><?php echo esc_html($item['title']) ?></span>

										<?php if($item['location'] != "") : ?>
											<span class="location">
												<?php if( $item['location_icon'] ){ ?>
													<i class="<?php echo $item['location_icon']; ?>"></i>
												<?php } ?>
												<?php echo esc_html($item['location']); ?>
											</span>
										<?php endif; ?>

										<?php  if($item['level'] != "") : ?>
											<span class="level">
												<?php if( $item['level_icon'] ){ ?>
													<i class="<?php echo $item['level_icon']; ?>"></i>
												<?php } ?>
												<?php echo esc_html($item['level']) ?>
											</span>
										<?php endif; ?>

										

										<?php if ($version === 'version_1') : ?>
											<span class="icon-accor" ><i class="<?php echo esc_attr( $icon_active ); ?>" id="<?php echo esc_attr($i) ?>" ></i></span>
										<?php endif ?>
									</div>
									
								</div>
								<!-- end sub-content -->
							</div>
							<div id="slide-<?php echo esc_attr($i) ?>" class="content " >
								<?php if( $item['speaker1_name'] || $item['speaker2_name'] ){ ?>
									<ul class="speakers">

										<?php if( $item['speaker1_name'] ){ ?>
											<li class="thumb_image">
												<?php if( $speaker1_img_200[0] ){ ?>
													<img src="<?php echo esc_url( $speaker1_img_200[0] ); ?>" alt="<?php echo esc_attr($item['speaker1_name']) ?>">
												<?php } ?>
												
												<div class="speaker_info">
													<?php if( $item['speaker1_link'] ){ ?>
														<a href="<?php echo $item['speaker1_link']; ?>" class="name">
															<?php echo $item['speaker1_name']; ?>
														</a>
													<?php }else{ ?>
														<div class="name">
															<?php echo $item['speaker1_name']; ?>
														</div>
													<?php } ?>
													
													<div class="speaker_job"><?php echo $item['speaker1_job']; ?></div>
													
													<?php if( $item['speaker1_icon1'] || $item['speaker1_icon2'] || $item['speaker1_icon3'] ){ ?>
														<ul class="social">
															<li>
																<a href="<?php echo $item['speaker1_icon1_link']; ?>" target="_blank"><i class="<?php echo $item['speaker1_icon1']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker1_icon2_link']; ?>" target="_blank"><i class="<?php echo $item['speaker1_icon2']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker1_icon3_link']; ?>" target="_blank"><i class="<?php echo $item['speaker1_icon3']; ?>"></i></a>
															</li>
														</ul>
													<?php } ?>
												</div>
												
											</li>

										<?php } ?>

										<?php if( $item['speaker2_name'] ){ ?>
											<li class="thumb_image">
												
												<?php if( $speaker2_img_200[0] ){ ?>
													<img src="<?php echo esc_url( $speaker2_img_200[0] ); ?>" alt="<?php echo esc_attr($item['speaker2_name']) ?>">
												<?php } ?>

												<div class="speaker_info">
													<?php if( $item['speaker2_link'] ){ ?>
														<a href="<?php echo $item['speaker2_link']; ?>" class="name">
															<?php echo $item['speaker2_name']; ?>
														</a>
													<?php }else{ ?>
														<div class="name">
															<?php echo $item['speaker2_name']; ?>
														</div>
													<?php } ?>
													
													<div class="speaker_job"><?php echo $item['speaker2_job']; ?></div>

													<?php if( $item['speaker2_icon1'] || $item['speaker2_icon2'] || $item['speaker2_icon3'] ){ ?>
														<ul class="social">
															<li>
																<a href="<?php echo $item['speaker2_icon1_link']; ?>" target="_blank"><i class="<?php echo $item['speaker2_icon1']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker2_icon2_link']; ?>" target="_blank"><i class="<?php echo $item['speaker2_icon2']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker2_icon3_link']; ?>" target="_blank"><i class="<?php echo $item['speaker2_icon3']; ?>"></i></a>
															</li>
														</ul>
													<?php } ?>
												</div>
												
											</li>
										<?php } ?>

										<?php if( $item['speaker3_name'] ){ ?>
											<li class="thumb_image">
												
												<?php if( $speaker3_img_200[0] ){ ?>
													<img src="<?php echo esc_url( $speaker3_img_200[0] ); ?>" alt="<?php echo esc_attr($item['speaker3_name']) ?>">
												<?php } ?>

												<div class="speaker_info">
													<?php if( $item['speaker3_link'] ){ ?>
														<a href="<?php echo $item['speaker3_link']; ?>" class="name">
															<?php echo $item['speaker3_name']; ?>
														</a>
													<?php }else{ ?>
														<div class="name">
															<?php echo $item['speaker3_name']; ?>
														</div>
													<?php } ?>
													
													<div class="speaker_job"><?php echo $item['speaker3_job']; ?></div>

													<?php if( $item['speaker3_icon1'] || $item['speaker3_icon2'] || $item['speaker3_icon3'] ){ ?>
														<ul class="social">
															<li>
																<a href="<?php echo $item['speaker3_icon1_link']; ?>" target="_blank"><i class="<?php echo $item['speaker3_icon1']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker3_icon2_link']; ?>" target="_blank"><i class="<?php echo $item['speaker3_icon2']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker3_icon3_link']; ?>" target="_blank"><i class="<?php echo $item['speaker3_icon3']; ?>"></i></a>
															</li>
														</ul>
													<?php } ?>
												</div>
												
											</li>
										<?php } ?>

										<?php if( $item['speaker4_name'] ){ ?>
											<li class="thumb_image">
												
												<?php if( $speaker4_img_200[0] ){ ?>
													<img src="<?php echo esc_url( $speaker4_img_200[0] ); ?>" alt="<?php echo esc_attr($item['speaker4_name']) ?>">
												<?php } ?>

												<div class="speaker_info">
													<?php if( $item['speaker4_link'] ){ ?>
														<a href="<?php echo $item['speaker4_link']; ?>" class="name">
															<?php echo $item['speaker4_name']; ?>
														</a>
													<?php }else{ ?>
														<div class="name">
															<?php echo $item['speaker4_name']; ?>
														</div>
													<?php } ?>
													
													<div class="speaker_job"><?php echo $item['speaker4_job']; ?></div>

													<?php if( $item['speaker4_icon1'] || $item['speaker4_icon2'] || $item['speaker4_icon3'] ){ ?>
														<ul class="social">
															<li>
																<a href="<?php echo $item['speaker4_icon1_link']; ?>" target="_blank"><i class="<?php echo $item['speaker4_icon1']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker4_icon2_link']; ?>" target="_blank"><i class="<?php echo $item['speaker4_icon2']; ?>"></i></a>
															</li>
															<li>
																<a href="<?php echo $item['speaker4_icon3_link']; ?>" target="_blank"><i class="<?php echo $item['speaker4_icon3']; ?>"></i></a>
															</li>
														</ul>
													<?php } ?>
												</div>
												
											</li>
										<?php } ?>

									</ul>
								<?php } ?>

								<?php if ($item['content'] != "") : ?>
									<div class="item-conten">
										<?php echo $item['content'] ?>
									</div>
								<?php endif ?>
								<?php if($item['text_button'] != "") : ?>
									<a class="button-text" href="<?php echo esc_attr($item['link']['url']) ?>"><?php echo esc_html($item['text_button']) ?></a>
								<?php endif ?>
							</div>

							<!-- end wp-content -->
						</div>
					</div>
					<?php
				endforeach;
			endif;
			?>
			
			<?php if (($settings['wp_time'] != '' || $settings['wp_title'] != "") && ($version === 'version_1')) : ?>
			<div class="time-title">
				<div class="time">
					<span><?php echo esc_html($settings['wp_time']) ?></span>
				</div>
				<div class="title-element">
					<span><?php echo esc_html($settings['wp_title']) ?></span>
				</div>
			</div>
		<?php endif ?>
	</div>
	<?php
}
}
