<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_lifevent_according_image_filter extends Widget_Base {

	public function get_name() {
		return 'ova_lifevent_according_image_filter';
	}

	public function get_title() {
		return __( 'Filter According Image Version 2', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-accordion';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_day',
			[
				'label' => __( 'Day', 'ova-framework' ),
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'day',
			[
				'label' => __( 'Day', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __('Month', 'ova-framework'),
			]
		);

		$repeater->add_control(
			'class_day_filter',
			[
				'label' => __( 'Id Day Filter', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'day_filter_1',
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => __( 'Tabs', 'ova-framework' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'day' => __('17 DECEMBER, 2019', 'ova-framework'),
						'class_day_filter' => __('day_filter_1', 'ova-framework'),
					],
					[
						'day' => __('18 DECEMBER, 2019', 'ova-framework'),
						'class_day_filter' => __('day_filter_2', 'ova-framework'),
					],
					[
						'day' => __('19 DECEMBER, 2019', 'ova-framework'),
						'class_day_filter' => __('day_filter_3', 'ova-framework'),
					],
					[
						'day' => __('20 DECEMBER, 2019', 'ova-framework'),
						'class_day_filter' => __('day_filter_4', 'ova-framework'),
					],
				],
				'title_field' => '{{{ day }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_room',
			[
				'label' => __( 'Room', 'ova-framework' ),
			]
		);



		$repeater_2 = new \Elementor\Repeater();

		$repeater_2->add_control(
			'room',
			[
				'label' => __( 'Room', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$repeater_2->add_control(
			'class_day_filter_r',
			[
				'label' => __( 'Id Day Filter', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'day_filter_1',
			]
		);

		$repeater_2->add_control(
			'class_room_filter',
			[
				'label' => __( 'Class Room Filter', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'room_filter_1',
			]
		);

		$this->add_control(
			'tabs_2',
			[
				'label' => __( 'Tabs', 'ova-framework' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater_2->get_controls(),
				'default' => [
					[
						'room' => __('Room 1', 'ova-framework'),
						'class_roo_filter' => __('room_filter_1', 'ova-framework'),
					],
					[
						'room' => __('Room 2', 'ova-framework'),
						'class_room_filter' => __('room_filter_2', 'ova-framework'),
					],
					[
						'room' => __('Room 3', 'ova-framework'),
						'class_room_filter' => __('room_filter_3', 'ova-framework'),
					],
					[
						'room' => __('Room 4', 'ova-framework'),
						'class_room_filter' => __('room_filter_4', 'ova-framework'),
					],
				],
				'title_field' => '{{{ room }}}',
			]
		);

		$this->end_controls_section();


	}

	protected function render() {
		$settings = $this->get_settings();
		$tabs = $settings['tabs'];
		$tab_2 = $settings['tabs_2'];
		?>
		<div class="ova-lifevent-according-image-filter">
			<div class="wp-content">
				<ul class="day">
					<?php if (!empty($tabs)) : foreach ($tabs as $item) : ?>
						<li data-id="<?php echo esc_attr($item['class_day_filter']) ?>" ><a href="javascript:void(0)"><?php echo esc_attr($item['day']) ?></a></li>
					<?php endforeach; endif ?>
				</ul>
				<ul class="room">
					<?php if (!empty($tab_2)) : foreach ($tab_2 as $item_2) : ?>
						<li class="<?php echo esc_attr($item_2['class_day_filter_r']) ?> " data-id="<?php echo esc_attr($item_2['class_room_filter']) ?>" ><a href="javascript:void(0)"><?php echo esc_attr($item_2['room']) ?></a></li>
					<?php endforeach; endif ?>
				</ul>
				
			</div>
		</div>
		<?php

	}
// end render
}


